==> botlog-1.0.3.tar.gz: botlog/src/BotlogSql.php <==
<?php

namespace Drupal\botlog;

use Drupal\Core\Database\Connection;

/**
 * SQL for the botlog module.
 */
class BotlogSql {

  /**
   * Database connection.
   *
   * @var Drupal\Core\Database\Connection
   */
  protected $dbh;

  /**
   * Constructor.
   *
   * @param Drupal\Core\Database\Connection $dbh
   *   The database handle.
   */
  public function __construct(Connection $dbh) {
    $this->dbh = $dbh;
  }

  /**
   * Delete all entries with the supplied entry ID.
   *
   * @param int $bid
   *   The entry ID.
   *
   * @return int
   *   The number of deleted entries.
   */
  public function escapeLike($ip) {
    return '%' . $this->dbh->escapeLike($ip) . '%';
  }

  /**
   * Delete all entries with the supplied entry ID.
   *
   * @param int $bid
   *   The entry ID.
   *
   * @return int
   *   The number of deleted entries.
   */
  public function deleteById($bid) {
    return $this->dbh->delete('botlog')->condition('bid', $bid)->execute();
  }

  /**
   * Delete all entries with the supplied IP.
   *
   * @param int $ip
   *   The ip.
   *
   * @return int
   *   The number of deleted entries.
   */
  public function deleteByIp($ip) {
    return $this->dbh->delete('botlog')->condition('ip', $ip)->execute();
  }

  /**
   * Delete old entries.
   *
   * @param int $timestamp
   *   The max time of entries to delete.
   *
   * @return int
   *   The number of deleted entries.
   */
  public function deleteByTime($timestamp) {
    return $this->dbh->delete('botlog')
      ->condition('timestamp', $timestamp, '<=')
      ->condition('level', 2, '<=')
      ->execute();
  }

  /**
   * Get the offer's expired status.
   *
   * @param int $ip
   *   The IP.
   * @param int $status
   *   The status.
   *
   * @return int
   *   One if IP has an error set.
   */
  public function getErrorStatus($ip, $status) {
    $stmt = "SELECT 1 FROM {botlog} WHERE ip = :ip AND level = :level";
    $vals = [
      ':ip'    => $ip,
      ':level' => $status,
    ];
    return $this->dbh->queryRange($stmt, 0, 1, $vals)->fetchField();
  }

  /**
   * Fetch the row count.
   *
   * @return int
   *   The number of rows in the botlog table for the IP.
   */
  public function getCount($ip = '') {
    if ($ip) {
      return $this->dbh->query("SELECT COUNT(*) FROM {botlog} WHERE ip LIKE :ip", [':ip' => $ip])->fetchField();
    }
    return $this->dbh->query("SELECT COUNT(*) FROM {botlog}")->fetchField();
  }

  /**
   * Fetch the row count.
   *
   * @param int $ip
   *   The IP.
   *
   * @return int
   *   The number of rows in the botlog table for the IP.
   */
  public function getIpCount($ip) {
    return $this->dbh->query("SELECT COUNT(*) FROM {botlog} WHERE ip = :ip", [':ip' => $ip])->fetchField();
  }

  /**
   * Insert a monotoring entry.
   *
   * @param array $fields
   *   An array of the monotoring fields.
   *
   * @return object
   *   A new InsertQuery object for this connection.
   */
  public function insertIp(array $fields) {
    return $this->dbh->insert('botlog')->fields($fields)->execute();
  }

  /**
   * Fetch all the events.
   *
   * @param int $start
   *   The starting offset.
   * @param int $limit
   *   The query limit.
   *
   * @return array
   *   An array of event objects.
   */
  public function selectAllEvents($start = NULL, $limit = 100) {
    if (is_numeric($start) && intval($limit)) {
#dump($this->dbh->queryRange("SELECT * FROM {botlog} ORDER BY timestamp DESC", $start, $limit)->__toString());
      return $this->dbh->queryRange("SELECT * FROM {botlog} ORDER BY timestamp DESC", $start, $limit)->fetchAll();
    }
#dump($this->dbh->query("SELECT * FROM {botlog} ORDER BY timestamp DESC")->__toString());
    return $this->dbh->query("SELECT * FROM {botlog} ORDER BY timestamp DESC")->fetchAll();
  }


  /**
   * Search suggestions.
   *
   * @param string $ngram
   *   The requested ngram.
   * @param int $start
   *   The starting offset.
   * @param int $limit
   *   The query limit.
   *
   * @return array
   *   An array of suggestion objects.
   */
  public function search($ip, $start = NULL, $limit = 100) {
    $args = [':ip' => $ip];

    if (is_numeric($start) && intval($limit)) {
#dump($this->dbh->query("SELECT * FROM {botlog} WHERE ip LIKE :ip ORDER BY ip ASC", $args)->__toString());
      return $this->dbh->queryRange("SELECT * FROM {botlog} WHERE ip LIKE :ip ORDER BY ip ASC", $start, $limit, $args)->fetchAll();
    }
#dump($this->dbh->query("SELECT * FROM {botlog} WHERE ip LIKE :ip ORDER BY ip ASC", $args)->__toString());
    return $this->dbh->query("SELECT * FROM {botlog} WHERE ip LIKE :ip ORDER BY ip ASC", $args)->fetchAll();
  }

  /**
   * Fetch the error.
   *
   * @param int $bid
   *   The error ID.
   *
   * @return object
   *   The error row.
   */
  public function selectEvent($bid) {
    return $this->dbh->query("SELECT * FROM {botlog} WHERE bid = :bid", [':bid' => $bid])->fetchObject();
  }

}

==> botlog-1.0.4.tar.gz: botlog/src/BotlogSql.php <==
<?php

namespace Drupal\botlog;

use Drupal\Core\Database\Connection;

/**
 * SQL for the botlog module.
 */
class BotlogSql {

  /**
   * Database connection.
   *
   * @var Drupal\Core\Database\Connection
   */
  protected $dbh;

  /**
   * Constructor.
   *
   * @param Drupal\Core\Database\Connection $dbh
   *   The database handle.
   */
  public function __construct(Connection $dbh) {
    $this->dbh = $dbh;
  }

  /**
   * Escape the string for a LIKE SQL statemant.
   *
   * @param int $ip
   *   The IP search string.
   *
   * @return string
   *   An escpaped string with the "%" prefix and suffix.
   */
  public function escapeLike($ip) {
    return '%' . $this->dbh->escapeLike($ip) . '%';
  }

  /**
   * Delete all entries with the supplied entry ID.
   *
   * @param int $bid
   *   The entry ID.
   *
   * @return int
   *   The number of deleted entries.
   */
  public function deleteById($bid) {
    return $this->dbh->delete('botlog')->condition('bid', $bid)->execute();
  }

  /**
   * Delete all entries with the supplied IP.
   *
   * @param int $ip
   *   The ip.
   *
   * @return int
   *   The number of deleted entries.
   */
  public function deleteByIp($ip) {
    return $this->dbh->delete('botlog')->condition('ip', $ip)->execute();
  }

  /**
   * Delete old entries.
   *
   * @param int $timestamp
   *   The max time of entries to delete.
   *
   * @return int
   *   The number of deleted entries.
   */
  public function deleteByTime($timestamp) {
    return $this->dbh->delete('botlog')
      ->condition('timestamp', $timestamp, '<=')
      ->condition('level', 0, '!=')
      ->condition('level', 3, '!=')
      ->execute();
  }

  /**
   * Fetch the row count.
   *
   * @return int
   *   The number of rows in the botlog table for the IP.
   */
  public function getCount($ip = '') {
    if ($ip) {
      return $this->dbh->query("SELECT COUNT(*) FROM {botlog} WHERE ip LIKE :ip", [':ip' => $ip])->fetchField();
    }
    return $this->dbh->query("SELECT COUNT(*) FROM {botlog}")->fetchField();
  }

  /**
   * Fetch the row count.
   *
   * @param int $ip
   *   The IP.
   *
   * @return int
   *   The number of rows in the botlog table for the IP.
   */
  public function getIpCount($ip) {
    return $this->dbh->query("SELECT COUNT(*) FROM {botlog} WHERE ip = :ip", [':ip' => $ip])->fetchField();
  }

  /**
   * Insert a monotoring entry.
   *
   * @param array $fields
   *   An array of the monotoring fields.
   *
   * @return object
   *   A new InsertQuery object for this connection.
   */
  public function insertIp(array $fields) {
    return $this->dbh->insert('botlog')->fields($fields)->execute();
  }

  /**
   * Get the offer's expired status.
   *
   * @param int $ip
   *   The IP.
   * @param int $status
   *   The status.
   *
   * @return int/null
   *   One if the IP/level exists.
   */
  public function ipHasLevel($ip, $status) {
    $stmt = "SELECT 1 FROM {botlog} WHERE ip = :ip AND level = :level";
    $vals = [
      ':ip'    => $ip,
      ':level' => $status,
    ];
    return $this->dbh->queryRange($stmt, 0, 1, $vals)->fetchField();
  }

  /**
   * Fetch all the events.
   *
   * @param int $start
   *   The starting offset.
   * @param int $limit
   *   The query limit.
   *
   * @return array
   *   An array of event objects.
   */
  public function selectAllEvents($start = NULL, $limit = 100) {
    if (is_numeric($start) && intval($limit)) {
      return $this->dbh->queryRange("SELECT * FROM {botlog} ORDER BY timestamp DESC", $start, $limit)->fetchAll();
    }
    return $this->dbh->query("SELECT * FROM {botlog} ORDER BY timestamp DESC")->fetchAll();
  }


  /**
   * Search suggestions.
   *
   * @param string $ngram
   *   The requested ngram.
   * @param int $start
   *   The starting offset.
   * @param int $limit
   *   The query limit.
   *
   * @return array
   *   An array of suggestion objects.
   */
  public function search($ip, $start = NULL, $limit = 100) {
    $args = [':ip' => $ip];

    if (is_numeric($start) && intval($limit)) {
      return $this->dbh->queryRange("SELECT * FROM {botlog} WHERE ip LIKE :ip ORDER BY ip ASC", $start, $limit, $args)->fetchAll();
    }
    return $this->dbh->query("SELECT * FROM {botlog} WHERE ip LIKE :ip ORDER BY ip ASC", $args)->fetchAll();
  }

  /**
   * Fetch the error.
   *
   * @param int $bid
   *   The error ID.
   *
   * @return object
   *   The error row.
   */
  public function selectEvent($bid) {
    return $this->dbh->query("SELECT * FROM {botlog} WHERE bid = :bid", [':bid' => $bid])->fetchObject();
  }

}
